# CORE SUPPLIERS

It is a module of the Research CORE ERM which implements the models related to suppliers.

- Suppliers info
- Suppliers categories

## Installation

```shell script
pip install core-suppliers
```

# *Enterprise Resources Management* - Research CORE

CORE is an ERM platform developed in within a research environment and aims to automatize 
internal management processes, like human resources, orders, budgets, suppliers, funds, equipment \rooms accesses and maintenance and publications.

The project is distributed as an open-source project to facilitate the adaptation of the 
ERM to each institution's needs.

![core printscreen](https://github.com/research-core/core-server/raw/master/docs/static/core.png "Core publications printscreen")
